package org.firstinspires.ftc.teamcode.cometbots;

import static org.firstinspires.ftc.teamcode.PedroConstants.MAX_POWER;

import androidx.annotation.NonNull;

import com.acmerobotics.dashboard.telemetry.TelemetryPacket;
import com.acmerobotics.roadrunner.Action;
import com.acmerobotics.roadrunner.SequentialAction;
import com.acmerobotics.roadrunner.SleepAction;
import com.acmerobotics.roadrunner.ftc.Actions;
import com.qualcomm.robotcore.hardware.Gamepad;
import com.qualcomm.robotcore.hardware.HardwareMap;

import org.firstinspires.ftc.robotcore.external.Telemetry;
import org.firstinspires.ftc.teamcode.pedroPathing.follower.Follower;
import org.firstinspires.ftc.teamcode.states.FieldStates;
import org.firstinspires.ftc.teamcode.subsystem.DualMotorSliderSubsystem;
import org.firstinspires.ftc.teamcode.subsystem.MotorsSubsystem;

public class CometBotAutoDevelopment {

    /*
    Subsystems
     */
    private DualMotorSliderSubsystem dualSlides;

    /*
    Controllers
     */
    public Gamepad gamepad1;
    public Gamepad gamepad2;
    public Gamepad currentGamepad1;
    public Gamepad currentGamepad2;
    public Gamepad previousGamepad1;
    public Gamepad previousGamepad2;

    private Follower follower;

    public CometBotAutoDevelopment(HardwareMap hardwareMap, Gamepad gamepad1, Gamepad gamepad2) {
        dualSlides = new DualMotorSliderSubsystem(hardwareMap);
        this.gamepad1 = gamepad1;
        this.gamepad2 = gamepad2;
        currentGamepad1 = new Gamepad();
        currentGamepad2 = new Gamepad();
        previousGamepad1 = new Gamepad();
        previousGamepad2 = new Gamepad();
        follower = new Follower(hardwareMap);
    }
    
    public void init() {
        dualSlides.init();
        follower.setMaxPower(MAX_POWER);
        follower.startTeleopDrive();
    }

    public void update() {
        previousGamepad1.copy(currentGamepad1);
        currentGamepad1.copy(gamepad1);
        previousGamepad2.copy(currentGamepad2);
        currentGamepad2.copy(gamepad2);

        /*
        Check if dpad_up/down is being pressed for slides
        */
        dualSlides.update();
        dualSlidesToLowBucketPosition();
        dualSlidesToHighBucketPosition();

        follower.setTeleOpMovementVectors(-gamepad1.left_stick_y, -gamepad1.left_stick_x, -gamepad1.right_stick_x);
        follower.update();
    }

    private void dualSlidesToHighBucketPosition() {
        if (currentGamepad1.dpad_up && !previousGamepad1.dpad_up) {
            dualSlides.toHighBucketPosition();
        }
    }

    private void dualSlidesToLowBucketPosition() {
        if (currentGamepad1.dpad_down && !previousGamepad1.dpad_down) {
            dualSlides.toLowBucketPosition();
        }
    }

}
